@@ -65,7 +65,7 @@ namespace eval ::teapotclient {
 
 			vfs::zip::Unmount $mntfd $file
 		} else {
-			exec unzip -d $dir -n -qq $urlcachefile
+			exec unzip -d $dir -n -qq $file
 		}
 	}
 
@@ -75,11 +75,11 @@ namespace eval ::teapotclient {
 	set osTeapotToLocal(tcl) [list *]
 	set osTeapotToLocal(linux-*) [list linux]
 	set osTeapotToLocal(win32) [list windows]
-	set osTeapotToLocal(solaris*) [list solaris]
+	set osTeapotToLocal(solaris*) [list solaris sunos]
 	set osTeapotToLocal(freebsd) [list freebsd_*]
 	set osTeapotToLocal(irix) [list irix_*]
 
-	set cpuTeapotToLocal(ix86) [list x86 intel]
+	set cpuTeapotToLocal(ix86) [list x86 intel i?86 i86pc]
 	set cpuTeapotToLocal(sparc) [list sun4*]
 	set cpuTeapotToLocal(universal) [list *]
 	set cpuTeapotToLocal(powerpc) [list ppc]
@@ -292,8 +292,8 @@ namespace eval ::teapotclient {
 			} else {
 				foreach {teapot localvariants} [array get osTeapotToLocal] {
 					foreach local $localvariants {
-						if {[string match $limitos $local] || [string match $local $limitos]} {
-							if {[string match $teapot $arch_os] || [string match $arch_os $teapot]} {
+						if {[string match -nocase $limitos $local] || [string match -nocase $local $limitos]} {
+							if {[string match -nocase $teapot $arch_os] || [string match -nocase $arch_os $teapot]} {
 								set isCompatOS 1
 								break
 							}
@@ -308,13 +308,13 @@ namespace eval ::teapotclient {
 			set isCompatCPU 0
 			if {$arch == "tcl"} {
 				set isCompatCPU 1
-			} elseif {[string match $limitcpu $arch_cpu]} {
+			} elseif {[string match -nocase $limitcpu $arch_cpu]} {
 				set isCompatCPU 1
 			} else {
 				foreach {teapot localvariants} [array get cpuTeapotToLocal] {
 					foreach local $localvariants {
-						if {[string match $limitcpu $local] || [string match $local $limitcpu]} {
-							if {[string match $teapot $arch_cpu] || [string match $arch_cpu $teapot]} {
+						if {[string match -nocase $limitcpu $local] || [string match -nocase $local $limitcpu]} {
+							if {[string match -nocase $teapot $arch_cpu] || [string match -nocase $arch_cpu $teapot]} {
 								set isCompatCPU 1
 								break
 							}
